import type { ChangeEvent, InputHTMLAttributes, LabelHTMLAttributes, ReactElement, ReactNode, RefObject } from "react";
import type { CSSObject } from "styled-components";
import type { PositionProps, SpaceProps, TypographyProps } from "styled-system";
export interface CheckboxProps extends Omit<LabelHTMLAttributes<HTMLLabelElement>, "onChange">, SpaceProps, TypographyProps, PositionProps {
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The reference of the input element.
     * @default undefined
     */
    inputRef?: RefObject<HTMLInputElement>;
    /**
     * The input checkbox attributes.
     *
     * <a href="https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#Attributes" target="_blank" rel="noopener noreferrer">Attributes</a> applied to the `input` checkbox element.
     *
     * @default {}
     */
    inputProps?: InputHTMLAttributes<HTMLInputElement>;
    /**
     * Specifies the initial state: whether or not the checkbox is selected.
     * @default false
     */
    defaultChecked?: boolean;
    /**
     * If `true`, the component is checked.
     * @default undefined
     */
    checked?: boolean;
    /**
     * The label text to show.
     * @default undefined
     */
    label?: ReactNode;
    /**
     * The label placement.
     * @default "right"
     */
    labelPlacement?: "left" | "right";
    /**
     * The color of the component.
     * @default "primary"
     */
    color?: "primary" | "secondary";
    /**
     * If `true`, the component appears indeterminate.
     * This does not set the native input element to indeterminate due to inconsistent behavior across browsers.
     * However, we set a `data-indeterminate` attribute on the input to allow get the value from direct js.
     * @default false
     */
    indeterminate?: boolean;
    /**
     * The icon to display when the component is unchecked.
     * @default undefined
     */
    uncheckedIcon?: ReactElement;
    /**
     * The icon to display when the component is checked.
     * @default undefined
     */
    checkedIcon?: ReactElement;
    /**
     * The icon to display when the component is indeterminate.
     * @default undefined
     */
    indeterminateIcon?: ReactElement;
    /**
     * The size of the icon
     * @default 24
     */
    iconSize?: number;
    /**
     * `true` to show the checkbox with a total height of 32px instead of 44px.
     * @default false
     */
    compact?: boolean;
    /**
     * If `true`, the checkbox will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the ripple effect will be disabled.
     * @default false
     */
    disableRipple?: boolean;
    /**
     * Callback fired when the state is changed. It receives the params `event`.
     * @default undefined
     */
    onChange?: (event: ChangeEvent<HTMLInputElement>) => void;
}
