import type { SelectedFilters, Sources } from "../entity";
import type Filter from "../Filter";
import TreeNodeFilter from "./TreeNodeFilter";
/**
 * Tree data structure optimized to filter in logarithmic time.
 *
 * - Having the selectedFilters matrix:
 * [[f1[f1-child1, f1-child2], f2[f2-child1]], [f3, f4, f5]]
 *
 * - Will generate the next tree:
 *
 *                       root
 *                      /    \
 *                    /       \
 *                  /          \
 *                and1         and2
 *               /   \        / | \
 *             /      \      /  |  \
 *           f1       f2   f3  f4  f5
 *         /   \        \
 *       /      \        \
 *  f1-child1  f1-child2 f2-child1
 */
export default class TreeFilter {
    private readonly root;
    /**
     * Constructor by default.
     */
    constructor();
    /**
     * Search a filter.
     *
     * Algorithm complexity of O(log n)
     *
     * @param filter the filter to find.
     * @param depth the depth in the tree you want to go, -1 to find in the hole tree.
     * @param node the actual node to check.
     * @returns the node if the filter exists, undefined otherwise.
     */
    search(filter: Filter, depth?: number, node?: TreeNodeFilter): TreeNodeFilter | undefined;
    /**
     * Insert nodes to the root node.
     *
     * Algorithm complexity of O(log n)
     *
     * @param f array of filter or a filter.
     * @param selectedFilters the selected filters map.
     * @param sourceKey if you want to override the key in the filter
     * definitions, otherwise undefined.
     * @param node the actual node to check.
     */
    insert(f: Filter[] | Filter, selectedFilters: SelectedFilters, sourceKey: string | undefined, node?: TreeNodeFilter): void;
    /**
     * Execute the selected nodes, and update the sources map.
     *
     * Algorithm complexity of O(log n)
     *
     * @param sources a Map with the source data to be updated.
     * @param dataSources accumulator data map.
     * @param node the actual node to check.
     */
    filterSelectedNodes(sources: Sources, dataSources?: Map<string, any[]>, node?: TreeNodeFilter): void;
    /**
     * Get the filter results per each node and update the result filters map.
     *
     * Algorithm complexity of O(n)
     *
     * @param filteredSources a Map with the filtered source data.
     * @param sources a Map with the source data.
     * @param result a map with the results for each filter that will be updated.
     * @param node the actual node to check.
     */
    getFilterResultsByNode(filteredSources: Sources, sources: Sources, result: Map<string, any>, node?: TreeNodeFilter): void;
    private getSourceKey;
    private getData;
    private removeDuplicates;
}
