import type { Sources } from "../entity";
import type Filter from "../Filter";
/**
 * Tree node implementation only to be used with the filters to speed the
 * filter calculations.
 *
 * This class only implements some operations from a tree node structure, the
 * necessary operations to boost the filter calculations.
 */
export default class TreeNodeFilter {
    private parent?;
    private left?;
    private right?;
    private depth?;
    private selected;
    private readonly children;
    private readonly filter?;
    /**
     * Constructor by default.
     */
    constructor(filter?: Filter);
    /**
     * Add children to the actual node in the left position.
     *
     * @param child the child node to add.
     */
    addChildLeft(child: TreeNodeFilter): void;
    /**
     * Add children to the actual node in the right position.
     *
     * @param child the child node to add.
     */
    addChildRight(child: TreeNodeFilter): void;
    /**
     * Insert children to this node, the selected filters will be always in
     * the left.
     *
     * @param filter the filter that represents a node.
     * @param selected true if the filter is selected, false otherwise.
     */
    insert(filter: Filter, selected: boolean): TreeNodeFilter;
    /**
     * Rotate the last child to the left, to the start.
     */
    rotateLeft(): void;
    /**
     * Run filter associated to this node.
     *
     * @param sources - Map of sources that contains the data to be filtered.
     */
    run(sources: Sources): any[];
    /**
     * @returns true if the node is the root node, false otherwise.
     */
    isRoot(): boolean;
    /**
     * @returns true if the node has parent, false otherwise.
     */
    hasParent(): boolean;
    /**
     * @returns the parent node of this node.
     */
    getParent(): TreeNodeFilter | undefined;
    /**
     * @returns true if the node has a left sibling, false otherwise.
     */
    hasLeft(): boolean;
    /**
     * @returns the left sibling of this node if exists.
     */
    getLeft(): TreeNodeFilter | undefined;
    /**
     * @returns true if the node has a right sibling, false otherwise.
     */
    hasRight(): boolean;
    /**
     * @returns the right sibling of this node if exists.
     */
    getRight(): TreeNodeFilter | undefined;
    /**
     * @returns the depth of the node from the root, 0 if is the root.
     */
    getDepth(): number;
    /**
     * Set the depth
     *
     * @param depth the new depth.
     */
    setDepth(depth: number): void;
    /**
     * @returns true if the node is selected.
     */
    isSelected(): boolean;
    /**
     * Set selected.
     *
     * @param selected if the node is selected or not.
     */
    setSelected(selected: boolean): void;
    /**
     * @returns true if the node doesn't have children, false otherwise.
     */
    hasChildren(): boolean;
    /**
     * @returns the fist children of the node.
     */
    getFirstChild(): TreeNodeFilter | undefined;
    /**
     * @returns the last children of the node.
     */
    getLastChild(): TreeNodeFilter | undefined;
    /**
     * @returns the filter associated to the node.
     */
    getFilter(): Filter | undefined;
}
