import type { ChangeEvent, InputHTMLAttributes, ReactElement, ReactNode, RefObject, TextareaHTMLAttributes } from "react";
import type { CSSObject } from "styled-components";
import type { BorderProps, ColorProps, FlexboxProps, LayoutProps, PositionProps, SpaceProps, TypographyProps } from "styled-system";
export interface BaseInputStyleProps extends ColorProps, TypographyProps, BorderProps {
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
}
export interface InputProps extends SpaceProps, TypographyProps, LayoutProps, FlexboxProps, PositionProps {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The reference of the input element.
     * @default undefined
     */
    inputRef?: RefObject<HTMLInputElement>;
    /**
     * The input props.
     *
     * <a href="https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#Attributes" target="_blank" rel="noopener noreferrer">Attributes</a> applied to the `input` element.
     *
     * @default {}
     */
    inputProps?: InputHTMLAttributes<HTMLInputElement> & TextareaHTMLAttributes<HTMLTextAreaElement>;
    /**
     * The input styled system props.
     *
     * @default {}
     */
    inputStyledProps?: BaseInputStyleProps;
    /**
     * The type of the input.
     * <a href="https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#%3Cinput%3E_types" target="_blank" rel="noopener noreferrer">Input types</a> applied to the `input` element.
     *
     * @default "text"
     */
    type?: string;
    /**
     * The variant of the input.
     * @default "default"
     */
    variant?: "default" | "success" | "warning" | "error" | "naked";
    /**
     * The label of the input, if added it will be placed on the top left of the input.
     * @default undefined
     */
    label?: ReactNode;
    /**
     * Meta description of the input, if added it will be placed on the top right of the input.
     * @default undefined
     */
    meta?: ReactNode;
    /**
     * The helper text of the input, if added it will be placed on bottom of the input
     * @default undefined
     */
    helperText?: ReactNode;
    /**
     * The icon to add in front of the helper text if this is set it.
     * @default undefined
     */
    helperIcon?: ReactNode;
    /**
     * The `input` element value. Use when the component is controlled.
     * @default undefined
     */
    value?: string | number;
    /**
     * The default `input` element value. Use when the component is not controlled.
     * @default undefined
     */
    defaultValue?: string | number;
    /**
     * The placeholder of the `input` element.
     * @default undefined
     */
    placeholder?: string;
    /**
     * Component to place in the beginning of the component, it can be an icon.
     * @default undefined
     */
    startAdornment?: ReactElement;
    /**
     * Component to place in the end of the component, it can be an icon.
     * @default undefined
     */
    endAdornment?: ReactElement;
    /**
     * The width of the outline border.
     * @default undefined
     */
    outlineWidth?: string;
    /**
     * `true` to convert the input into a textarea
     * @default false
     */
    multiple?: boolean;
    /**
     * `true` to show the input with a min height of 24px instead of 36px.
     * @default false
     */
    compact?: boolean;
    /**
     * If `true`, the input will take up the full width of its container.
     * @default false
     */
    fullWidth?: boolean;
    /**
     * If the input should remain focus.
     * @default false
     */
    forceFocus?: boolean;
    /**
     * If `true`, the input will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Component to show when no options match search.
     */
    noOptionsValue?: ReactElement;
    /**
     * Callback fired when the value is changed.
     * @default undefined
     */
    onChange?: (value: string, event: ChangeEvent<HTMLInputElement>) => void;
    /**
     * Callback fired when the input is focused.
     * @default undefined
     */
    onFocus?: (value: string, event: ChangeEvent<HTMLInputElement>) => void;
    /**
     * Callback fired when the input has lost focused..
     * @default undefined
     */
    onBlur?: (value: string, event: ChangeEvent<HTMLInputElement>) => void;
}
