import type { ElementType, HTMLAttributes, ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { FlexboxProps, LayoutProps, SpaceProps, TypographyProps } from "styled-system";
import type { MenuDividerProps } from "../MenuDivider";
import type { MenuItemProps } from "../MenuItem";
import type { MenuItemGroupProps } from "../MenuItemGroup";
import type { SubMenuProps } from "../MenuSubMenu";
export type SubMenuTriggers = "click" | "hover";
export type MenuEvent = {
    menuItemId: string;
    selected: boolean;
    selectedIds: string[];
    open: boolean;
    openIds: string[];
};
export interface MenuProps extends Omit<HTMLAttributes<HTMLUListElement>, "onClick" | "onSelect">, SpaceProps, TypographyProps, LayoutProps, FlexboxProps {
    /**
     * The children `MenuItem`, `SubMenu`, `MenuDivider`.
     */
    children: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The component used for the root node.
     * @default "ul"
     */
    as?: ElementType;
    /**
     * Type of menu:
     * <br/>- Vertical mode
     * <br/>- Horizontal mode
     * <br/>- Inline mode used to create side menus that can be collapsed,
     * a good option to be used with a `Drawer`.
     *
     * @default "vertical"
     */
    mode?: "vertical" | "horizontal" | "inline";
    /**
     * Specifies the collapsed status when menu is inline mode.
     * @default false
     */
    inlineCollapsed?: boolean;
    /**
     * Allows selection of multiple items.
     * @default false
     */
    multiple?: boolean;
    /**
     * Allows selecting menu items
     * @default true
     */
    selectable?: boolean;
    /**
     * Array with the ids of the currently selected menu items.
     * @default undefined
     */
    selectedIds?: string[];
    /**
     * Array with the ids of the currently opened sub menus.
     * @default undefined
     */
    openIds?: string[];
    /**
     * Override and force to use a specific triggers to open the sub menus.
     * @default "click"
     */
    triggersSubMenu?: SubMenuTriggers | SubMenuTriggers[];
    /**
     * `true` to show the menu items with a min height of 32px instead of 48px.
     * @default false
     */
    compact?: boolean;
    /**
     * Whether menu is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the ripple effect will be disabled.
     * @default false
     */
    disableRipple?: boolean;
    /**
     * Callback fired when click on a menu item. A default function to be used in every menu item
     * instead of create one per menu item.
     *
     * `({ menuItemId, selected, selectedIds, open, openIds}: MenuEvent, event: SyntheticEvent) => {}`
     *
     * @default undefined
     */
    onClick?: (menuEvent: MenuEvent, event: SyntheticEvent) => void;
    /**
     * Called when a menu item is selected.
     *
     * `({ menuItemId, selected, selectedIds, open, openIds}: MenuEvent, event: SyntheticEvent) => {}`
     *
     * @default undefined
     */
    onSelect?: (menuEvent: MenuEvent, event: SyntheticEvent) => void;
    /**
     * Called when a menu item is unselected.
     *
     * `({ menuItemId, selected, selectedIds, open, openIds}: MenuEvent, event: SyntheticEvent) => {}`
     *
     * @default undefined
     */
    onDeselect?: (menuEvent: MenuEvent, event: SyntheticEvent) => void;
    /**
     * Called when sub-menus are opened.
     *
     * `({ menuItemId, selected, selectedIds, open, openIds}: MenuEvent, event: SyntheticEvent) => {}`
     *
     * @default undefined
     */
    onOpen?: (menuEvent: MenuEvent, event: SyntheticEvent) => void;
    /**
     * Called when sub-menus are opened.
     *
     * `({ menuItemId, selected, selectedIds, open, openIds}: MenuEvent, event: SyntheticEvent) => {}`
     *
     * @default undefined
     */
    onClose?: (menuEvent: MenuEvent, event: SyntheticEvent) => void;
}
export type GenerateMenuProps = {
    /**
     * The id of the menu item.
     * @default undefined
     */
    id?: string;
    /**
     * The title or the label of the menu item.
     */
    name?: ReactNode;
    /**
     * Whether the menu item is a `MenuDivider` or not.
     * @default false
     */
    isMenuDivider?: boolean;
    /**
     * Whether the menu item is a `MenuItemGroup` or not.
     * @default false
     */
    isMenuItemGroup?: boolean;
    /**
     * An object with the props to add to the `MenuDivider`.
     * @default {}
     */
    menuDividerProps?: MenuDividerProps;
    /**
     * An object with the props to add to the `MenuItem`
     * @default {}
     */
    menuItemProps?: MenuItemProps;
    /**
     * An object with the props to add to the `MenuItemGroup`.
     * @default {}
     */
    menuItemGroupProps?: MenuItemGroupProps;
    /**
     * An object with the props to add to the `SubMenu`
     * @default {}
     */
    subMenuProps?: SubMenuProps;
    /**
     * Children elements of the menu item.
     * Mandatory field to generate a `SubMenu` or a `MenuItemGroup`.
     *
     * If `isMenuItemGroup` is true it will generate a  `MenuItemGroup` if no
     * it will generate a `SubMenu`.
     *
     * @default undefined
     */
    children?: GenerateMenuProps[];
};
