import type { BoundsStatic, DeltaStatic, Quill, RangeStatic, Sources, StringMap } from "quill";
import type { CSSProperties, HTMLAttributes, RefAttributes, RefObject } from "react";
export type QuillValue = string | DeltaStatic;
export type QuillRange = RangeStatic | null;
export interface QuillUnprivilegedEditor {
    getLength(): number;
    getText(index?: number, length?: number): string;
    getHTML(): string;
    getBounds(index: number, length?: number): BoundsStatic;
    getSelection(focus?: boolean): RangeStatic;
    getContents(index?: number, length?: number): DeltaStatic;
}
export type QuillOnChangeProps = {
    value: string;
    delta: DeltaStatic;
    source: Sources;
    editor: QuillUnprivilegedEditor;
};
export type QuillOnChangeSelectionProps = {
    selection: QuillRange;
    source: Sources;
    editor: QuillUnprivilegedEditor;
};
export type QuillOnFocusProps = {
    selection: QuillRange;
    source: Sources;
    editor: QuillUnprivilegedEditor;
};
export type QuillOnBlurProps = {
    previousSelection: QuillRange;
    source: Sources;
    editor: QuillUnprivilegedEditor;
};
export interface ReactQuillProps extends Omit<HTMLAttributes<HTMLDivElement>, "value" | "defaultValue" | "onChange" | "onFocus" | "onBlur"> {
    /**
     * A single React element that will be used as the editing area for Quill
     * in place of the default, which is a <div>.
     *
     * ! Be aware that re-render the children is costly, as it will cause the Quill editor to be recreated,
     * ! use the `value` prop for changing the content of the editor.
     *
     * ! You cannot use a `<textarea>`, as it is not a supported target.
     *
     * @default div
     */
    children?: React.ReactElement<any>;
    /**
     * The ref that will have the api method exposed.
     * @default undefined
     */
    reactQuillRef?: RefObject<ReactQuillHTMLElement>;
    /**
     * The generation number, the purpose of this field is to help to control the re-renders.
     * @default 0
     */
    generation?: number;
    /**
     * The ID of the component.
     * @default undefined
     */
    id?: string;
    /**
     * The className of the component.
     * @default undefined
     */
    className?: string;
    /**
     * The css object to override the styles on the opt-quill container.
     * @default undefined
     */
    style?: CSSProperties;
    /**
     * Value for the editor as a controlled component
     * Can be a string containing HTML or a <a href="https://quilljs.com/docs/delta/">quill delta</a>
     *
     * ! This value is a "semi-controlled mode" meaning that the edit is not prevented, but changing value will still replace the contents.
     *
     * @default undefined
     */
    value?: QuillValue;
    /**
     * Initial value for the editor as an uncontrolled component.
     * Can be a string containing HTML or a <a href="https://quilljs.com/docs/delta/">quill delta</a>
     * @default undefined
     */
    defaultValue?: QuillValue;
    /**
     * The default value for the empty editor.
     * @default undefined
     */
    placeholder?: string;
    /**
     * If `true` the editor won't allow changing its contents.
     * @default false
     */
    readOnly?: boolean;
    /**
     * If true, a pre tag is used for the editor area instead of the default div tag.
     * This prevents Quill from collapsing continuous whitespaces on paste.
     * @default false
     */
    preserveWhitespace?: boolean;
    /**
     * An array of formats to be enabled during editing.
     * All implemented formats are enabled by default if nothing is send.
     * @see <a href="https://quilljs.com/docs/formats/">Quill formats</a>
     * @default undefined
     */
    formats?: string[];
    /**
     * An object specifying which modules are enabled.
     * The editor toolbar is a commonly customized module.
     * @see <a href="https://quilljs.com/docs/modules/">Quill modules</a>
     * @default undefined
     */
    modules?: StringMap;
    /**
     * A HTML element.
     * The `container`used by quill to constrain the scroll.
     * @default undefined
     */
    scrollingContainer?: HTMLElement;
    /**
     * A HTML element.
     * The `container`used by quill to constrain position of popups.
     * @default document.body
     */
    container?: HTMLElement;
    /**
     * Called back with the new contents of the editor after change.
     * @default undefined
     */
    onChange?: (props: QuillOnChangeProps) => void;
    /**
     * Called back with the new selected range, or null when unfocused.
     * @default undefined
     */
    onChangeSelection?: (props: QuillOnChangeSelectionProps) => void;
    /**
     * Called when the editor becomes focused.
     * It will receive the new selection range.
     * @default undefined
     */
    onFocus?: (props: QuillOnFocusProps) => void;
    /**
     * Called when the editor loses focus.
     * It will receive the selection range it had right before losing focus.
     * @default undefined
     */
    onBlur?: (props: QuillOnBlurProps) => void;
}
export interface ReactQuillHTMLElement extends RefAttributes<HTMLDivElement> {
    /**
     * @returns The DOM element that represents the editing area.
     * @throws an error if the editing area can't be access.
     */
    getEditingArea: () => Element;
    /**
     * @returns the Quill editor instance.
     * @throws error if the editor is not yet instantiate.
     */
    getEditor: () => Quill;
    /**
     * @returns the quill editor value.
     */
    getEditorContents: () => QuillValue;
    /**
     * @returns the quill editor range selection.
     */
    getEditorSelection: () => QuillRange | undefined;
    /**
     * Replace the contents of the editor, but keep the previous selection hanging
     * around so that the cursor won't move.
     *
     * @params value the new Quill value.
     */
    setEditorContents: (value: QuillValue) => void;
    /**
     * Sets the editor selection programmatically.
     *
     * @params range the new Quill range selection.
     */
    setEditorSelection: (range: QuillRange | undefined) => void;
    /**
     * Sets the editor tab index.
     *
     * @params tabIndex the new Quill tab index.
     */
    setEditorTabIndex: (tabindex: number) => void;
    /**
     * Changes the read only of the editor without re-render the component.
     *
     * @params isReadOnly the new read only status for the Quill editor.
     */
    setEditorReadOnly: (isReadOnly: boolean) => void;
    /**
     * Force the trigger of the editor focus method.
     */
    focus: () => void;
    /**
     * Force the trigger of the editor blur method.
     */
    blur: () => void;
    /**
     * Instantiate the Quill editor.
     */
    instantiateEditor: () => void;
    /**
     * Destroy the Quill editor.
     *
     * ! Note it will remove the events and the ref values, this method is meant to be called an onUnMount.
     */
    destroyEditor: () => void;
}
