import type { ReactNode, RefAttributes, RefObject, SyntheticEvent } from "react";
import type { DropdownProps } from "../Dropdown";
import type { InputProps } from "../Input";
export type SelectValueType = string | number | string[] | number[];
export type SelectNodeProps = {
    label: string;
    value?: string | number;
    disabled?: boolean;
};
export interface SelectOptionProps extends SelectNodeProps {
    type?: "option" | "optgroup";
    options?: SelectOptionProps[];
}
export type SelectedOptionsEvent = {
    selectedValue?: SelectValueType;
    deselectedValue?: SelectValueType;
    options: SelectOptionProps[];
};
export interface SelectProps extends Omit<InputProps, "children" | "multiple" | "value" | "defaultValue" | "forceFocus"> {
    /**
     * The options of the select using the HTMLElement `option`.
     * @default undefined
     */
    children?: ReactNode;
    /**
     * The ref that will have the api method exposed.
     */
    selectRef?: RefObject<SelectHTMLElement>;
    /**
     * An array of options. An alternative method to add the options with an array of objects
     * instead of using the children.
     * @default undefined
     */
    options?: SelectOptionProps[];
    /**
     * The value or values if `multiple` is enabled. Use when the component is controlled.
     *
     * **If `multiple` is NOT enabled and an array is used it will only use the first item.**
     *
     * @default undefined
     */
    value?: SelectValueType;
    /**
     * The default, initial, value or values if `multiple` is enabled.
     *
     * **If `multiple` is NOT enabled and an array is used it will only use the first item.**
     *
     * @default undefined
     */
    defaultValue?: SelectValueType;
    /**
     * The value of the input text.
     * @default undefined
     */
    inputValue?: string;
    /**
     * Show clear button.
     * @default true
     */
    allowClear?: boolean;
    /**
     * Enable/Disable select multi options.
     * @default false
     */
    multiple?: boolean;
    /**
     * Enable/Disable collapsable options
     * only <optgroup> elements can be collapsed.
     * @default false
     */
    expandable?: boolean;
    /**
     * Enable/Disable show the selected options inside the select or below the select.
     *
     * Only works if `multiple` is true.
     *
     * @default true
     */
    infield?: boolean;
    /**
     * If `multiple` enabled and if is `true` the options will be shown as tags/chips.
     * @default false
     */
    tags?: boolean;
    /**
     * If `multiple` enabled a max options to show, if the number of selected options exceed this property a
     * text will be shown instead.
     *
     * Use `0` to just show a `Chip` with the `tagMaxCountPlaceholder`.
     *
     * @default undefined
     */
    tagMaxCount?: number;
    /**
     * If `multiple` enabled the text to be shown if the number of selected options are exceed.
     * @default undefined
     */
    tagMaxCountPlaceholder?: string | ((numberOfSelectedOptions: number) => string);
    /**
     * The label used when `multiple` is enabled and the `tags` is false.
     *
     * By default the selected label will be constructed as `${numberOfSelectedOptions}/${total} Selected`
     *
     * @default "Selected"
     */
    selectedLabel?: ReactNode | ((numberOfSelectedOptions: number, total: number) => string);
    /**
     * If `true`, filter the select options dropdown by the select input value, only shows the options that
     * contains or matches the select input value.
     *
     * Also this parameter can be a function, return `true` to include the option, the function has the shape of:
     *
     * @default false
     */
    filterOption?: boolean | ((node: SelectNodeProps, inputValue: string, menuSelectedIds: string[]) => boolean);
    /**
     * The label if the dropdown doesn't have any element to show.
     * @default "No Data"
     */
    noOptionsText?: ReactNode;
    /**
     * Callback fired when select and option.
     *
     * `({selectedValue, deselectedValue, options}: SelectedOptionsEvent, event: SyntheticEvent) => void`
     *
     * @default undefined
     */
    onSelect?: (selectedOptions: SelectedOptionsEvent, event?: SyntheticEvent) => void;
    /**
     * Callback fired when de select and option.
     *
     * `({selectedValue, deselectedValue, options}: SelectedOptionsEvent, event: SyntheticEvent) => void`
     *
     * @default undefined
     */
    onDeselect?: (selectedOptions: SelectedOptionsEvent, event?: SyntheticEvent) => void;
    /**
     * Callback fired when click on the clear button.
     * @default undefined
     */
    onClear?: (event: SyntheticEvent) => void;
    /**
     * Callback used to render a custom menu item group.
     * The item that you return **MUST** have a unique key. but you can use the label as key
     *
     * `(({value, label, disabled}: SelectNodeProps, items: ReactNode[], inputValue: string) => MenuItemGroup`
     *
     * @default undefined
     */
    itemGroupRenderer?: (node: SelectNodeProps, items: ReactNode[], inputValue: string) => ReactNode;
    /**
     * Callback to render a custom menu item.
     * The item that you return **MUST** have a unique key and you can use the value as key.
     *
     * `({value, label, disabled}: SelectNodeProps, inputValue: string, menuSelectedIds: string[]) => MenuItem`
     *
     * @default undefined
     */
    itemRenderer?: (node: SelectNodeProps, inputValue: string, menuSelectedIds: string[]) => ReactNode;
    /**
     * The select dropdown props.
     * @default {}
     */
    dropdownProps?: Omit<DropdownProps, "open" | "menu" | "contextMenu" | "arrow" | "overflowY">;
}
export interface SelectHTMLElement extends RefAttributes<HTMLInputElement> {
    /**
     * Trigger select dropdown open function.
     */
    open: () => void;
    /**
     * Trigger select dropdown close function.
     */
    close: () => void;
}
